==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/uk-UA/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Цей користувач може увійти',
    'activated_disabled_help_text' => 'Ви не можете редагувати статус активації для вашого власного облікового запису.',
    'assets_user'       => 'Вкладення призначено :name',
    'bulk_update_warn'	=> 'Ви збираєтесь змінити властивості :user_count користувачів. Будь ласка, зверніть увагу, що ви не можете змінити власні атрибути користувача, використовуючи цю форму, і ви повинні відредагувати свій власний користувач.',
    'bulk_update_help'	=> 'Ця форма дозволяє Вам оновити кілька користувачів за один раз. Заповніть тільки ті поля, які необхідно змінити. Будь-які вільні поля порожніми, залишаться без змін.',
    'current_assets'    => 'Активи на даний момент перевірено для цього користувача',
    'clone'             => 'Клонувати користувача',
    'contact_user'      => 'Контакт:name',
    'edit'              => 'Редагувати користувача',
    'filetype_info'     => 'Дозволені типи файлів - png, gif, jpg, jpeg, doc, docx, pdf, txt, zip і rar.',
    'history_user'      => 'Історія для :name',
    'info'				=> 'Інфо',
    'restore_user'		=> 'Натисніть тут, щоб відновити їх.',
    'last_login'        => 'Останній вхід',
    'ldap_config_text'  => 'Налаштування конфігурації LDAP можна знайти Адміністратора > Налаштування. (опціонально) вибране місце розташування буде встановлено для всіх імпортованих користувачів.',
    'print_assigned'    => 'Друкувати всі призначені',
    'email_assigned'    => 'Список адрес електронної пошти присвоєних',
    'user_notified'     => 'Користувач відправлений на email список призначених в даний час елементів.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Включати цього користувача при автоматичному призначенні ліцензій',
    'auto_assign_help'  => 'Пропустити цього користувача в автопризначенні ліцензій',
    'software_user'     => 'Програмне забезпечення перевірено :name',
    'send_email_help'   => 'Ви повинні вказати email адресу для цього користувача для відправки їм облікових даних. Електронна пошта може бути виконана лише при створенні користувача. Паролі зберігаються в хеші одностороння і не можуть бути завантажені після збереження.',
    'view_user'         => 'Переглянути користувача :name',
    'usercsv'           => 'Файл CSV',
    'two_factor_admin_optin_help' => 'Ваш поточний параметр адміністратора дозволяє вибіркове виконання двофакторної автентифікації.  ',
    'two_factor_enrolled' => 'Двофакторний пристрій 2FA зареєстровано ',
    'two_factor_active'   => 'Двофакторна автентифікація ',
    'user_deactivated'  => 'Користувач не може увійти',
    'user_activated'  => 'Користувач може увійти',
    'activation_status_warning' => 'Не змінюйте статус активації',
    'group_memberships_helpblock' => 'Лише суперадміністратори можуть редагувати членство в групах.',
    'superadmin_permission_warning' => 'Лише суперадміністратори можуть надавати доступ користувачу суперадміністратора.',
    'admin_permission_warning' => 'Тільки користувачі з правами адміністратора або більше можуть надати доступ адміністратора користувача.',
    'remove_group_memberships' => 'Видалити членство в групах',
    'warning_deletion_information' => 'Ви збираєтеся перевірити ВСІ елементи(і) з :count користувача(-ів) перераховані нижче. Супер адміністрування виділяються червоним кольором.',
    'update_user_assets_status' => 'Оновити всі медіафайли для цих користувачів до цього статусу',
    'checkin_user_properties' => 'Перевірити всі властивості, пов\'язані з цими користувачами',
    'remote_label'   => 'Це віддалений користувач',
    'remote'   => 'Пульт',
    'remote_help' => 'Це може бути корисно, якщо вам потрібно фільтрувати віддалених користувачів, які ніколи або рідко потрапляють у ваші фізичні місця.',
    'not_remote_label' => 'Це не віддалений користувач',
    'vip_label' => 'VIP-користувач',
    'vip_help' => 'Це може бути корисною для позначення важливих людей у вашій організації, якщо ви хочете впоратися з ними особливими способами.',
    'create_user' => 'Створення користувача',
    'create_user_page_explanation' => 'Інформація про обліковий запис, яку ви будете використовувати для першого доступу до сайту.',
    'email_credentials' => 'Облікові дані електронної пошти',
    'email_credentials_text' => 'Надіслати мої облікові дані на електронну адресу',
    'next_save_user' => 'Далі: збереження користувача',
    'all_assigned_list_generation' => 'Згенерований на:',
    'email_user_creds_on_create' => 'Надішліть цьому користувачеві їх облікові дані?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/uk-UA/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Цей користувач може увійти',
    'activated_disabled_help_text' => 'Ви не можете редагувати статус активації для вашого власного облікового запису.',
    'assets_user'       => 'Вкладення призначено :name',
    'bulk_update_warn'	=> 'Ви збираєтесь змінити властивості :user_count користувачів. Будь ласка, зверніть увагу, що ви не можете змінити власні атрибути користувача, використовуючи цю форму, і ви повинні відредагувати свій власний користувач.',
    'bulk_update_help'	=> 'Ця форма дозволяє Вам оновити кілька користувачів за один раз. Заповніть тільки ті поля, які необхідно змінити. Будь-які вільні поля порожніми, залишаться без змін.',
    'current_assets'    => 'Активи на даний момент перевірено для цього користувача',
    'clone'             => 'Клонувати користувача',
    'contact_user'      => 'Контакт:name',
    'edit'              => 'Редагувати користувача',
    'filetype_info'     => 'Дозволені типи файлів - png, gif, jpg, jpeg, doc, docx, pdf, txt, zip і rar.',
    'history_user'      => 'Історія для :name',
    'info'				=> 'Інфо',
    'restore_user'		=> 'Натисніть тут, щоб відновити їх.',
    'last_login'        => 'Останній вхід',
    'ldap_config_text'  => 'Налаштування конфігурації LDAP можна знайти Адміністратора > Налаштування. (опціонально) вибране місце розташування буде встановлено для всіх імпортованих користувачів.',
    'print_assigned'    => 'Друкувати всі призначені',
    'email_assigned'    => 'Список адрес електронної пошти присвоєних',
    'user_notified'     => 'Користувач відправлений на email список призначених в даний час елементів.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Включати цього користувача при автоматичному призначенні ліцензій',
    'auto_assign_help'  => 'Пропустити цього користувача в автопризначенні ліцензій',
    'software_user'     => 'Програмне забезпечення перевірено :name',
    'view_user'         => 'Переглянути користувача :name',
    'usercsv'           => 'Файл CSV',
    'two_factor_admin_optin_help' => 'Ваш поточний параметр адміністратора дозволяє вибіркове виконання двофакторної автентифікації.  ',
    'two_factor_enrolled' => 'Двофакторний пристрій 2FA зареєстровано ',
    'two_factor_active'   => 'Двофакторна автентифікація ',
    'user_deactivated'  => 'Користувач не може увійти',
    'user_activated'  => 'Користувач може увійти',
    'activation_status_warning' => 'Не змінюйте статус активації',
    'group_memberships_helpblock' => 'Лише суперадміністратори можуть редагувати членство в групах.',
    'superadmin_permission_warning' => 'Лише суперадміністратори можуть надавати доступ користувачу суперадміністратора.',
    'admin_permission_warning' => 'Тільки користувачі з правами адміністратора або більше можуть надати доступ адміністратора користувача.',
    'remove_group_memberships' => 'Видалити членство в групах',
    'warning_deletion_information' => 'Ви збираєтеся перевірити ВСІ елементи(і) з :count користувача(-ів) перераховані нижче. Супер адміністрування виділяються червоним кольором.',
    'update_user_assets_status' => 'Оновити всі медіафайли для цих користувачів до цього статусу',
    'checkin_user_properties' => 'Перевірити всі властивості, пов\'язані з цими користувачами',
    'remote_label'   => 'Це віддалений користувач',
    'remote'   => 'Пульт',
    'remote_help' => 'Це може бути корисно, якщо вам потрібно фільтрувати віддалених користувачів, які ніколи або рідко потрапляють у ваші фізичні місця.',
    'not_remote_label' => 'Це не віддалений користувач',
    'vip_label' => 'VIP-користувач',
    'vip_help' => 'Це може бути корисною для позначення важливих людей у вашій організації, якщо ви хочете впоратися з ними особливими способами.',
    'create_user' => 'Створення користувача',
    'create_user_page_explanation' => 'Інформація про обліковий запис, яку ви будете використовувати для першого доступу до сайту.',
    'email_credentials' => 'Облікові дані електронної пошти',
    'email_credentials_text' => 'Надіслати мої облікові дані на електронну адресу',
    'next_save_user' => 'Далі: збереження користувача',
    'all_assigned_list_generation' => 'Згенерований на:',
    'email_user_creds_on_create' => 'Надішліть цьому користувачеві їх облікові дані?',
    'department_manager' => 'Department Manager',
];
